Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(220)

Unified Diff: recipes/nacl.py

Issue 128403007: Adding fetch recipes for nacl, naclports, and depot_tools. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools
Patch Set: fix Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « recipes/depot_tools.py ('k') | recipes/naclports.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: recipes/nacl.py
diff --git a/recipes/chromium.py b/recipes/nacl.py
similarity index 71%
copy from recipes/chromium.py
copy to recipes/nacl.py
index 4eac6bdbb712dbb2b258a5987a27eab7f2c4570a..e1f2420ce6cfeced2d5304ce683581a335bd4aa1 100644
--- a/recipes/chromium.py
+++ b/recipes/nacl.py
@@ -1,4 +1,4 @@
-# Copyright (c) 2013 The Chromium Authors. All rights reserved.
+# Copyright (c) 2014 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
@@ -9,25 +9,24 @@ import recipe_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class Chromium(recipe_util.Recipe):
- """Basic Recipe class for Chromium."""
+class NaCl(recipe_util.Recipe):
+ """Basic Recipe class for NaCl."""
@staticmethod
def fetch_spec(props):
- url = 'https://chromium.googlesource.com/chromium/src.git'
- solution = { 'name' :'src',
+ url = ('https://chromium.googlesource.com/native_client/'
+ 'src/native_client.git')
+ solution = { 'name' :'native_client',
'url' : url,
'deps_file': '.DEPS.git',
'managed' : False,
'custom_deps': {},
'safesync_url': '',
}
- if props.get('webkit_rev', '') == 'ToT':
- solution['custom_vars'] = {'webkit_rev': ''}
spec = {
'solutions': [solution],
- 'svn_url': 'svn://svn.chromium.org/chrome',
- 'svn_branch': 'trunk/src',
+ 'svn_url': 'svn://svn.chromium.org/native_client',
+ 'svn_branch': 'trunk/src/native_client',
'svn_ref': 'git-svn',
}
if props.get('submodule_git_svn_spec'):
@@ -47,11 +46,11 @@ class Chromium(recipe_util.Recipe):
@staticmethod
def expected_root(_props):
- return 'src'
+ return 'native_client'
def main(argv=None):
- return Chromium().handle_args(argv)
+ return NaCl().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « recipes/depot_tools.py ('k') | recipes/naclports.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698